@@ -24,32 +24,46 @@ CrossEditor.prototype = {
 	},
 	createMenu: function(){
 
-		var cmds = ['undo',
-		'redo',
-		'fontsize',
-		'bold',
-		'underline',
-		'forecolor',
-		'removeformat' ];
+		var cmds = [
+			'undo',
+			'redo',
+			'fontsize',
+			'bold',
+			'underline',
+			'forecolor',
+			'removeformat',
+			'createlink',
+			'unlink'
+		];
+
+		var alts = {
+			'undo':'元に戻す',
+			'redo':'やり直し',
+			'fontsize':'フォントサイズ',
+			'bold':'太字',
+			'underline':'下線',
+			'forecolor':'文字の色',
+			'removeformat':'修飾の取り消し',
+			'createlink':'リンク',
+			'unlink':'リンクの取り消し'
+		};
+
 
 		cmds.each(function(cmd){
 			var menu = document.createElement('li');
 			var icon = document.createElement('img');
 			icon.src  = this.img_path + cmd + '.gif';
-			icon.alt = cmd;
+			icon.alt = alts[cmd];
 			menu.appendChild(icon);
 
-			if(cmd=='forecolor'){
+			if (cmd=='forecolor'){
 				menu.id = 'pallete_button';
 				$('menu').appendChild(menu);
 				return;
-			}
-
-			if (cmd=='fontsize'){
+			} else if (cmd=='fontsize'){
 				this.createSelect();
-			} else {
-				var opt = false;
 			}
+			var opt = false;
 
 			Event.observe(menu, 'mousedown', function(){
 				this.exCom(cmd, opt)
@@ -63,6 +77,11 @@ CrossEditor.prototype = {
 		try{
 			if (cmd=='fontsize'){
 				opt = $('fsize').selectedIndex + 1;
+			} else if (cmd=='createlink'){
+			    opt = prompt('URLを入力:', 'http://');
+			    if (opt == null) {
+			    	return;
+			  	}
 			}
 			this.doc.execCommand(cmd, false, opt);
 		}catch(e){
@@ -92,6 +111,9 @@ CrossEditor.prototype = {
 		);
 		select.id = 'fsize';
 		select.style.fontSize = '10px';
+		Event.observe(select, 'change', function(){
+			this.exCom('fontsize', false)
+		}.bind(this));
 		menu.appendChild(column);
 		menu.appendChild(select);
 		$('menu').appendChild(menu);
