@@ -2,7 +2,7 @@
 /* ========================================================================
  - [libs/rkt_manip(ulation).php]
  -      DB操作クラス
- -      Copyright (c) 2005-2006 Yujiro Takahashi
+ -      Copyright (c) 2005-2007 Yujiro Takahashi
  - ライセンス:
  -      This source file is subject to version 3.0 of the PHP license,
  -      that is available at http://www.php.net/license/3_0.txt
@@ -13,6 +13,7 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/
  - 更新履歴：
+ -      [2007/03/11] 入力データのエスケープ処理をRKT_validateへ移行
  -      [2006/05/19] privateの関数をpublickに変更（query関連）
  -      [2005/06/01] コンストラクタ引数変更、DB接続オジェクトを追加
  -      [2005/05/12] グローバルスコープ・フォーム入力関連を修正
@@ -390,24 +391,6 @@ class RKT_manip extends RKT_validate
         return $this->action_flag;
     }
 
-    /**
-     * 文字のエスケープ処理など
-     *
-     * @access private
-     * @parmas string $value 入力情報
-     * @return string
-     */
-    function escape_character($value)
-    {
-        $value = trim($value);
-        if ($this->magic_quotes_gpc) {
-            $value = stripslashes($value);
-        }
-
-        $value = $this->objdb->quote($value);
-        return trim($value, "'");
-    }
-
     /**
      * 外部入力の設定
      *
@@ -424,12 +407,12 @@ class RKT_manip extends RKT_validate
         if(is_array($validate_info)){
             extract($validate_info);
         }
-        $type = empty($type)? 'required':$type;
-        $option = empty($option)? null:$option;
+        $type     = empty($type)? 'required':$type;
+        $option   = empty($option)? null:$option;
         $required = empty($required)? false:$required;
-        $tags = empty($tags)? '':$tags;
+        $effect   = empty($effect)? array('RKT_validate', 'escape_character'):$effect;
 
-        if (!$this->validate($type, $key, $option, $required)){
+        if (!$this->validate($type, $key, $option, $required, $effect)){
             $this->values[$key] = '';
             return false;
         }
@@ -439,13 +422,11 @@ class RKT_manip extends RKT_validate
         if ($type === 'date'){
             $value = RKT_calendar::joinDate($value);
         }
-        $value = $this->escape_character($value);
-        $this->values[$key] = strip_tags($value, $tags);
+        $this->values[$key] = $value;
 
         return true;
     }
 
-
     /**
      * フォームから飛んでくるカレントID取得
      *
@@ -669,7 +650,7 @@ class RKT_manip extends RKT_validate
     {
         $set = '';
         foreach ($this->values as $key=>$value) {
-            $value = ($value==='')?'NULL':"'".$value."'";
+            $value = ($value===''||$value===null)?'NULL':$this->objdb->quote($value);
             $set .= $this->key_quote.$key.$this->key_quote.'='.$value.',';
         }
         $where = $this->key_quote.$this->primary_key.$this->key_quote."='".$this->cur_id."'";
@@ -703,8 +684,8 @@ class RKT_manip extends RKT_validate
         $column = implode($this->key_quote.','.$this->key_quote,$keys);
 
         $values = array();
-        foreach ($this->values as $value) {
-            $values[] = ($value==='')?'NULL':"'".$value."'";
+        foreach ($this->values as $key=>$value) {
+            $values[] = ($value===''||$value===null)?'NULL':$this->objdb->quote($value);
         }
         $value = implode(',',$values);
 
