@@ -21,6 +21,7 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/rktSNS/
  - 更新履歴：
+ -      [2007/04/13] キリ番メールが連続して送信されるエラー修正
  -      [2007/02/13] 公開レベルを保持
  -      [2006/09/20] $this->base['uri_separator']を追加
  -      [2006/08/28] あしあと処理をメンバ関数に所持
@@ -68,6 +69,12 @@ class WAP_friend extends RKT_webapp
      */
     var $ref_friend = 0;
 
+    /**
+     * アクセスログの挿入結果
+     * @var integer
+     */
+    var $ins_accesslog = false;
+
     /**
      * 表示公開レベル
      * @var integer
@@ -348,7 +355,7 @@ class WAP_friend extends RKT_webapp
                         $this->account['id'].','.
                         "'".$unique."'".
                     ')';
-            $this->objdb->exec($sql);
+            $this->ins_accesslog = $this->objdb->exec($sql);
         }
     }
 
@@ -360,6 +367,9 @@ class WAP_friend extends RKT_webapp
      */
     function send_mail($footprint)
     {
+        if (empty($this->ins_accesslog)){
+            return ;
+        }
         $sql=
             'SELECT '.
                 'nickname '.
