@@ -21,6 +21,7 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/rktSNS/
  - 更新履歴：
+ -      [2007/02/02] カテゴリ選択更新時エラーを修正
  -      [2006/09/17] do_query_select()のforach() Warning を除去
  -      [2006/09/17] PDFサポート分岐を追加
  -      [2006/09/17] system()を廃止し、include_onceで読み込みdia_book.phpを実行
@@ -506,6 +507,38 @@ class webapp extends WAP_private
         $this->Assign('categorys', $list);
     }
 
+    /**
+     * 選択済みカテゴリの取得
+     *
+     * @access private
+     * @return interger     データ操作結果
+     */
+    function get_selected()
+    {
+        $ref_book = $this->objmnp->getCurID();
+        $select = array();
+        $sql=
+            'SELECT '.
+                'ref_category '.
+            'FROM '.
+                DB_PREFIX.'dia_bookselect '.
+            'WHERE '.
+                'ref_diary ='.$this->ref_diary.' AND '.
+                'ref_book ='.$ref_book;
+        $stmt = $this->objdb->prepare($sql); 
+        $stmt->execute(); 
+        $result = $stmt->fetchAll(PDO_FETCH_ASSOC);
+        if (empty($result)){
+            return $select;
+        }
+        
+        foreach ($result as $value){
+            $select[$value['ref_category']] = $value['ref_category'];
+        }
+
+        return $select;
+    }
+
     /**
      * データ操作設定・実行
      *
@@ -515,6 +548,7 @@ class webapp extends WAP_private
     function do_query_select()
     {
         $ref_book = $this->objmnp->getCurID();
+        $selected = $this->get_selected();
         $sql=
             'SELECT '.
                 'id '.
@@ -531,9 +565,13 @@ class webapp extends WAP_private
 
         foreach ($result as $value){
             if (empty($this->dia_bookselect[$value['id']])){
-                $this->delete_select($value['id'], $ref_book);
+                if (!empty($selected[$value['id']])){
+                    $this->delete_select($value['id'], $ref_book);
+                }
             } else {
-                $this->insert_select($value['id'], $ref_book);
+                if (empty($selected[$value['id']])){
+                    $this->insert_select($value['id'], $ref_book);
+                }
             }
         } // foreach ($result as $value)
 
