@@ -20,6 +20,7 @@
 --      yujiro@rakuto.net
 --      http://rakuto.net/rktSNS/
 -- 更新履歴：
+--      [2007/04/21] 問合せ内容を修正、問合せ対応を追加
 --      [2007/02/02] 日記の未読コメントflagを追加
 --      [2007/01/30] メッセージの添付画像(sns_fri_picture)を追加
 --      [2007/01/21] お友達のお友達名簿を修正
@@ -980,20 +981,37 @@ CREATE TABLE sns_inq_category (
 CREATE SEQUENCE seq_sns_inq_inquire start 1 increment 1 maxvalue 9223372036854775807 minvalue 1 cache 1;
 CREATE TABLE sns_inq_inquire (
   id integer DEFAULT nextval('seq_sns_inq_inquire'::text) NOT NULL,
-  modify timestamp without time zone NOT NULL,
-  regist_date timestamp without time zone NOT NULL,
+  modify timestamp NOT NULL,
+  regist_date timestamp NOT NULL,
   ref_category integer,
   ref_account integer,
   status integer NOT NULL,
+  flag integer default 0,
   name varchar(128) NOT NULL,
   url varchar(128),
-  email bytea,
+  email blob,
   comment text NOT NULL,
+  PRIMARY KEY  (id)
+);
+
+-- 
+-- 問合せ対応
+-- 
+CREATE SEQUENCE seq_sns_inq_response start 1 increment 1 maxvalue 9223372036854775807 minvalue 1 cache 1;
+CREATE TABLE sns_inq_response (
+  id integer DEFAULT nextval('seq_sns_inq_response'::text) NOT NULL,
+  modify timestamp NOT NULL,
+  regist_date timestamp NOT NULL,
+  ref_inquire integer,
+  ref_account integer NOT NULL,
+  send integer,
   subject varchar(255) NOT NULL,
   body text NOT NULL,
   PRIMARY KEY  (id)
 );
 
+
+
 -- --------------------------------------------------------
 -- 
 -- システムからの記事　カテゴリマスター情報
